@@ -8,15 +8,8 @@
 #ifndef RTOOLS_H_
 #define RTOOLS_H_
 
-namespace R {
-#include <R.h>
-#include <Rinternals.h>
-#include <Rmath.h>
-}
-
 #include <rtools/get_value.h>
 #include <rtools/rObject.h>
 #include <rtools/rList.h>
-#include <rtools/rStream.h>
 
 #endif /* RTOOLS_H_ */
