@@ -7,12 +7,12 @@ x <- sim.data$x
 classes <- sim.data$classes
 
 ### Define grouping
-
-set.seed(100L)
-grouping <- sample(1:100, replace = TRUE, size = 400)
+grouping <- 1:400
+grouping[1:5] <- 1
+grouping[6:10] <- 2 
 
 ## Lambda sequence
-lambda <- msgl.lambda.seq(x, classes, grouping = grouping, alpha = .5, d = 100L, lambda.min = 0.05, standardize = FALSE)
+lambda <- msgl.lambda.seq(x, classes, grouping = grouping, alpha = .5, d = 25L, lambda.min = 0.05, standardize = FALSE)
 
 ## Sparse group lasso
 
@@ -21,4 +21,4 @@ fit1a <- msgl(x, classes, grouping = grouping, alpha = .5, lambda = lambda, stan
 # (Forced) Sparse x
 fit1b <- msgl(x, classes, grouping = grouping, alpha = .5, lambda = lambda, sparse.data = TRUE, standardize = FALSE)
 
-if(max(abs(fit1a$beta[[100]]-fit1b$beta[[100]])) > 1e-10) stop()
\ No newline at end of file
+if( sum(predict(fit1b, x)$classes != predict(fit1a, x)$classes) > 10 ) stop()
