@@ -10,4 +10,4 @@ classes <- sim.data$classes
 lambda <- msgl.lambda.seq(x, classes, alpha = .5, d = 100L, lambda.min = 0.01, standardize = FALSE)
 lambda1 <- msgl.lambda.seq(x, classes, alpha = .5, d = 100L, lambda.min = 0.01, sparse.data = TRUE, standardize = FALSE)
 
-if(max(abs(lambda-lambda1)) != 0) stop()
\ No newline at end of file
+if(max(abs(lambda-lambda1)) > 1e-10) stop()
\ No newline at end of file
